==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/CommandJobLimitsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.CommandJobLimitsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Command Job limit class.
 * @property jobLimitsType
 * Expected value is 'Command'.
 * @property timeout The max run duration in ISO 8601 format, after which the job will be cancelled. Only supports duration with precision as low as Seconds.
 */
public data class CommandJobLimitsArgs(
    public val jobLimitsType: Output<String>,
    public val timeout: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.CommandJobLimitsArgs> {
    override fun toJava(): com.pulumi.azurenative.machinelearningservices.inputs.CommandJobLimitsArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.CommandJobLimitsArgs.builder()
            .jobLimitsType(jobLimitsType.applyValue({ args0 -> args0 }))
            .timeout(timeout?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CommandJobLimitsArgs].
 */
@PulumiTagMarker
public class CommandJobLimitsArgsBuilder internal constructor() {
    private var jobLimitsType: Output<String>? = null

    private var timeout: Output<String>? = null

    /**
     * @param value
     * Expected value is 'Command'.
     */
    @JvmName("tmqobptjoafqycgi")
    public suspend fun jobLimitsType(`value`: Output<String>) {
        this.jobLimitsType = value
    }

    /**
     * @param value The max run duration in ISO 8601 format, after which the job will be cancelled. Only supports duration with precision as low as Seconds.
     */
    @JvmName("ewuahxijiuhrycej")
    public suspend fun timeout(`value`: Output<String>) {
        this.timeout = value
    }

    /**
     * @param value
     * Expected value is 'Command'.
     */
    @JvmName("eqxmsexqukhrefhm")
    public suspend fun jobLimitsType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.jobLimitsType = mapped
    }

    /**
     * @param value The max run duration in ISO 8601 format, after which the job will be cancelled. Only supports duration with precision as low as Seconds.
     */
    @JvmName("ybbdhbbpgjoqmlfd")
    public suspend fun timeout(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timeout = mapped
    }

    internal fun build(): CommandJobLimitsArgs = CommandJobLimitsArgs(
        jobLimitsType = jobLimitsType ?: throw PulumiNullFieldException("jobLimitsType"),
        timeout = timeout,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/CommandJobLimitsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.CommandJobLimitsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Command Job limit class.
 * @property jobLimitsType
 * Expected value is 'Command'.
 * @property timeout The max run duration in ISO 8601 format, after which the job will be cancelled. Only supports duration with precision as low as Seconds.
 */
public data class CommandJobLimitsArgs(
    public val jobLimitsType: Output<String>,
    public val timeout: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.CommandJobLimitsArgs> {
    override fun toJava(): com.pulumi.azurenative.machinelearningservices.inputs.CommandJobLimitsArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.CommandJobLimitsArgs.builder()
            .jobLimitsType(jobLimitsType.applyValue({ args0 -> args0 }))
            .timeout(timeout?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CommandJobLimitsArgs].
 */
@PulumiTagMarker
public class CommandJobLimitsArgsBuilder internal constructor() {
    private var jobLimitsType: Output<String>? = null

    private var timeout: Output<String>? = null

    /**
     * @param value
     * Expected value is 'Command'.
     */
    @JvmName("omolgovcahjchyth")
    public suspend fun jobLimitsType(`value`: Output<String>) {
        this.jobLimitsType = value
    }

    /**
     * @param value The max run duration in ISO 8601 format, after which the job will be cancelled. Only supports duration with precision as low as Seconds.
     */
    @JvmName("uolpvwxdvpgyagin")
    public suspend fun timeout(`value`: Output<String>) {
        this.timeout = value
    }

    /**
     * @param value
     * Expected value is 'Command'.
     */
    @JvmName("hkceevahcluvjnpj")
    public suspend fun jobLimitsType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.jobLimitsType = mapped
    }

    /**
     * @param value The max run duration in ISO 8601 format, after which the job will be cancelled. Only supports duration with precision as low as Seconds.
     */
    @JvmName("bmuxktqqruwvywlx")
    public suspend fun timeout(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timeout = mapped
    }

    internal fun build(): CommandJobLimitsArgs = CommandJobLimitsArgs(
        jobLimitsType = jobLimitsType ?: throw PulumiNullFieldException("jobLimitsType"),
        timeout = timeout,
    )
}
